package de.uni_passau.fim.seibt.gitwrapper.repo;

import de.uni_passau.fim.seibt.gitwrapper.process.ProcessExecutor;

import java.util.Optional;
import java.util.function.Function;
import java.util.logging.Logger;

/**
 *  A {@link Branch} is a named {@link Reference} to a git branch pointing to an {@link Commit}.
 */
public class Branch extends Reference {

    private static final Logger LOG = Logger.getLogger(Branch.class.getCanonicalName());

    /**
     * Constructs an object referencing an existing git branch.
     *
     * @param repo the repo this branch is part of
     * @param name the branch name
     */
    Branch(Repository repo, String name) {
        super(repo, name);
    }

    /**
     * Checks this branch out, and tries to pull changes on this current branch.
     *
     * @return true if the pull was successful
     */
    public boolean pull() {
        if (!repo.checkout(this)) {
            return false;
        }

        Optional<ProcessExecutor.ExecRes> fetch = git.exec(repo.getDir(), "pull");
        Function<ProcessExecutor.ExecRes, Boolean> toBoolean = res -> {
            boolean failed = git.failed(res);

            if (failed) {
                LOG.warning(() -> String.format("Pull of %s failed.", this));
            }

            return !failed;
        };

        return fetch.map(toBoolean).orElse(false);
    }

    /**
     * Returns the id of the {@link Commit} this reference is currently pointing to.
     *
     * @return the id of the {@link Commit} under this branch
     */
    @Override
    public String getId() {
        return repo.toHash(id).orElse(id);
    }

    /**
     * Reruns the branch name.
     *
     * @return the branch name
     */
    public String getName() {
        return id;
    }
}
